@@ -9,12 +9,12 @@ from json import dumps, loads
 from alist import AlistClient
 
 
-def alist_update_115_cookie(
+def alist_update_115_cookies(
     client: AlistClient, 
     cookie: str, 
     only_not_work: bool = False, 
 ):
-    """更新 alist 中有关 115 的存储的 cookie
+    """更新 alist 中有关 115 的存储的 cookies
     """
     storages = client.admin_storage_list()["data"]["content"]
     for storage in storages:
